@@ -13,8 +13,7 @@
 using namespace std;
 using namespace FBB;
 
-string keywords = 
-
+/*
 "alignas "
 "alignof and compl explicit new requires typedef and_eq concept extern not "
 "bool delete if private switch void break do inline protected template "
@@ -28,6 +27,106 @@ string keywords =
 "while char else mutable reinterpret_cast true xor class enum namespace "
 "char16_t char32_t noexcept static_assert thread_local "
 "return" ;
+*/
+
+    // http://en.cppreference.com/w/cpp/keyword
+string keywords = R"(
+alignas
+alignof
+and
+and_eq
+asm
+atomic_cancel
+atomic_commit
+atomic_noexcept
+auto
+bitand
+bitor
+bool
+break
+case
+catch
+char
+char16_t
+char32_t
+class
+compl
+concept
+const
+constexpr
+const_cast
+continue
+co_await
+co_return
+co_yield
+decltype
+default
+delete
+do
+double
+dynamic_cast
+else
+enum
+explicit
+export
+extern
+false
+float
+for
+friend
+goto
+if
+import
+inline
+int
+long
+module
+mutable
+namespace
+new
+noexcept
+not
+not_eq
+nullptr
+operator
+or
+or_eq
+private
+protected
+public
+register
+reinterpret_cast
+requires
+return
+short
+signed
+sizeof
+static
+static_assert
+static_cast
+struct
+switch
+synchronized
+template
+this
+thread_local
+throw
+true
+try
+typedef
+typeid
+typename
+union
+unsigned
+using
+virtual
+void
+volatile
+wchar_t
+while
+xor
+xor_eq 
+)";
 
 struct Support: public TableSupport
 {
