@@ -8,7 +8,6 @@
 #include "parserbase.h"
 #include "../scanner/scanner.h"
 
-
 #undef Parser
 class Parser: public ParserBase
 {
@@ -21,11 +20,13 @@ class Parser: public ParserBase
 
     private:
         template <typename Type>
-            Type exec(char c, Type left, Type right);
+        Type exec(char c, Type left, Type right);
+
         template <typename Type>
-            Type neg(Type op);
+        Type neg(Type op);
+
         template <typename Type>
-            Type convert();
+        Type convert();
 
         void display(int x);
         void display(double x);
@@ -39,13 +40,13 @@ class Parser: public ParserBase
 
     // support functions for parse():
 
-        void executeAction(int d_production);
+        void executeAction(int d_ruleNr);
         void errorRecovery();
-        int lookup();
+        int lookup(bool recovery);
         void nextToken();
+        void print__();
 };
 
-
 inline double Parser::d(int i)
 {
     return i;
@@ -68,19 +69,19 @@ Type Parser::neg(Type op)
 template <typename Type>
 Type Parser::convert()
 {
-    Type ret = FBB::A2x(d_scanner.YYText());
+    Type ret = FBB::A2x(d_scanner.matched());
     d_rpn << " " << ret << " ";
     return ret;
 }
 
 inline void Parser::error(char const *msg)
 {
-    std::cerr << msg << std::endl;
+    std::cerr << msg << '\n';
 }
 
 inline int Parser::lex()
 {
-    return d_scanner.yylex();
+    return d_scanner.lex();
 }
 
 inline void Parser::print()
