@@ -1,23 +1,15 @@
     #include "monitor.ih"
 
-//  void Monitor::killChild(map<int, Child *>::value_type it)
-//  {
-//      if (kill(it.second->pid(), SIGTERM))
-//          cerr << "Couldn't kill process " << it.second->pid() << endl;
-//  }
-
 //KILL
-    void Monitor::killChild(map<int, Child *>::value_type it)
+    void Monitor::killChild(MapIntChild::value_type it)
     {
         if (kill(it.second->pid(), SIGTERM))
-            cerr << "Couldn't kill process " << it.second->pid() << endl;
+            cerr << "Couldn't kill process " << it.second->pid() << '\n';
 
         // reap defunct child process
         int status = 0;
         while( waitpid( it.second->pid(), &status, WNOHANG) > -1)
-        {};
-
-        return result;
+            ;
     }
 //=
 //EXIT
@@ -25,22 +17,20 @@
     {
         for_each(d_child.begin(), d_child.end(), killChild);
         if (msg.length())
-            cerr << msg << endl;
+            cerr << msg << '\n';
         throw value;
     }
 //=
 //INIT
     void (Monitor::*Monitor::s_handler[sizeofCommands])(int, string const &);
 
-    void Monitor::initialize()
+    int Monitor::initialize()
     {
-        if (s_handler[UNKNOWN] != 0)    // already initialized
-            return;
-
         s_handler[UNKNOWN] =    &Monitor::unknown;
         s_handler[START] =      &Monitor::createNewChild;
         s_handler[EXIT] =       &Monitor::exiting;
         s_handler[STOP] =       &Monitor::stopChild;
         s_handler[TEXT] =       &Monitor::sendChild;
+        return 0;
     }
 //=
