@@ -38,7 +38,7 @@
 
     int main()
     {
-        Object out("'main object'");
+        Object out{ "'main object'" };
         try
         {
             out.fun();
