@@ -1,8 +1,8 @@
     #include <iostream>
     #include "add.h"
 
-    int fun(int (*f)(int const &lvalue, int const &rvalue));
-    double fun(double (*f)(double const &lvalue, double const &rvalue));
+    int fun(int (*f)(int const &lhs, int const &rhs));
+    double fun(double (*f)(double const &lhs, double const &rhs));
 
     int main()
     {
