@@ -1,11 +1,11 @@
 #include <iostream>
-#include <experimental/filesystem>
+#include <filesystem>
 
 // explicitly link against stdc++fs:
 //
 //      gx absolute.cc -lstdc++fs
 
-namespace fs = std::experimental::filesystem;
+namespace fs = std::filesystem;
 
 int main()
 {
