@@ -1,12 +1,12 @@
 #include <iostream>
 #include <unordered_map>
-#include <experimental/filesystem>
+#include <filesystem>
 
 // explicitly link against stdc++fs:
 //
 //      gx statusknown.cc -lstdc++fs
 
-namespace fs = std::experimental::filesystem;
+namespace fs = std::filesystem;
 using namespace std;
 
 //demo
